@@ -10,7 +10,7 @@ key_only_resters = {
     "doi": "mp-149",
     "wulff": "mp-149",
     "charge_density": "mp-1936745",
-    "robocrys": "mp-149",
+    "provenance": "mp-149",
 }
 
 search_only_resters = [
@@ -25,7 +25,7 @@ special_resters = [
     "charge_density",
 ]
 
-ignore_generic = ["provenance"]  # temp
+ignore_generic = ["robocrys", "_user_settings"]  # temp
 
 
 mpr = MPRester()
@@ -41,7 +41,9 @@ def test_generic_get_methods(rester):
     name = rester.suffix.replace("/", "_")
     if name not in ignore_generic:
         if name not in key_only_resters:
-            doc = rester.query({"limit": 1}, fields=[rester.primary_key])[0]
+            doc = rester._query_resource_data(
+                {"limit": 1}, fields=[rester.primary_key]
+            )[0]
             assert isinstance(doc, rester.document_model)
 
             if name not in search_only_resters:
